@@ -6,8 +6,10 @@ from django.contrib.auth import login, authenticate
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth.models import User
 from django.core import signing
+from django.core.mail import EmailMultiAlternatives
 from django.http import JsonResponse
 from django.shortcuts import redirect, render
+from django.template.loader import render_to_string
 from django.urls import reverse, reverse_lazy
 from django.utils.translation import gettext_lazy as _
 
@@ -16,8 +18,8 @@ from esi.decorators import token_required
 from esi.models import Token
 
 from django_registration.backends.activation.views import (
-    RegistrationView as BaseRegistrationView, 
-    ActivationView as BaseActivationView, 
+    RegistrationView as BaseRegistrationView,
+    ActivationView as BaseActivationView,
     REGISTRATION_SALT
 )
 from django_registration.signals import user_registered
@@ -52,7 +54,7 @@ def dashboard(request):
         .filter(character_ownership__user=request.user)\
         .select_related()\
         .order_by('character_name')
-        
+
     context = {
         'groups': groups,
         'characters': characters
@@ -63,7 +65,7 @@ def dashboard(request):
 @login_required
 @token_required(scopes=settings.LOGIN_TOKEN_SCOPES)
 def main_character_change(request, token):
-    logger.debug("main_character_change called by user %s for character %s" % (request.user, token.character_name))
+    logger.debug(f"main_character_change called by user {request.user} for character {token.character_name}")
     try:
         co = CharacterOwnership.objects.get(character__character_id=token.character_id, user=request.user)
     except CharacterOwnership.DoesNotExist:
@@ -71,7 +73,7 @@ def main_character_change(request, token):
             co = CharacterOwnership.objects.create_by_token(token)
         else:
             messages.error(
-                request, 
+                request,
                 _('Cannot change main character to %(char)s: character owned by a different account.') % ({'char': token.character_name})
             )
             co = None
@@ -137,8 +139,51 @@ class RegistrationView(BaseRegistrationView):
     form_class = RegistrationForm
     template_name = "public/register.html"
     email_body_template = "registration/activation_email.txt"
+    email_body_template_html = "registration/activation_email_html.txt"
     email_subject_template = "registration/activation_email_subject.txt"
-    success_url = reverse_lazy('registration_complete') 
+    success_url = reverse_lazy('registration_complete')
+
+    def send_activation_email(self, user):
+        """
+        Implement our own way to send a mail to make sure we
+        send a RFC conform multipart email
+        :param user:
+        :type user:
+        """
+
+        activation_key = self.get_activation_key(user)
+        context = self.get_email_context(activation_key)
+        context["user"] = user
+
+        # email subject
+        subject = render_to_string(
+            template_name=self.email_subject_template,
+            context=context,
+            request=self.request,
+        )
+        subject = "".join(subject.splitlines())
+
+        # plaintext email body part
+        message = render_to_string(
+            template_name=self.email_body_template,
+            context=context,
+            request=self.request,
+        )
+
+        # html email body part
+        message_html = render_to_string(
+            template_name=self.email_body_template_html,
+            context=context,
+            request=self.request,
+        )
+
+        # send it
+        user.email_user(
+            subject,
+            message,
+            settings.DEFAULT_FROM_EMAIL,
+            **{'html_message': message_html},
+        )
 
     def get_success_url(self, user):
         if not getattr(settings, 'REGISTRATION_VERIFY_EMAIL', True):
@@ -154,7 +199,7 @@ class RegistrationView(BaseRegistrationView):
         if not getattr(settings, 'REGISTRATION_VERIFY_EMAIL', True):
             # Keep the request so the user can be automagically logged in.
             setattr(self, 'request', request)
-        return super(RegistrationView, self).dispatch(request, *args, **kwargs)
+        return super().dispatch(request, *args, **kwargs)
 
     def register(self, form):
         user = User.objects.get(pk=self.request.session.get('registration_uid'))
@@ -173,7 +218,7 @@ class RegistrationView(BaseRegistrationView):
         return signing.dumps(obj=[getattr(user, User.USERNAME_FIELD), user.email], salt=REGISTRATION_SALT)
 
     def get_email_context(self, activation_key):
-        context = super(RegistrationView, self).get_email_context(activation_key)
+        context = super().get_email_context(activation_key)
         context['url'] = context['site'].domain + reverse('registration_activate', args=[activation_key])
         return context
 
@@ -181,12 +226,12 @@ class RegistrationView(BaseRegistrationView):
 # Step 3
 class ActivationView(BaseActivationView):
     template_name = "registration/activate.html"
-    success_url = reverse_lazy('registration_activation_complete')    
-    
+    success_url = reverse_lazy('registration_activation_complete')
+
     def validate_key(self, activation_key):
         try:
             dump = signing.loads(activation_key, salt=REGISTRATION_SALT,
-                                 max_age=settings.ACCOUNT_ACTIVATION_DAYS * 86400)
+                                max_age=settings.ACCOUNT_ACTIVATION_DAYS * 86400)
             return dump
         except signing.BadSignature:
             return None
