@@ -10,9 +10,10 @@ from allianceauth.authentication.models import CharacterOwnership, State
 from allianceauth.eveonline.models import (
     EveCharacter, EveCorporationInfo, EveAllianceInfo
 )
-
 from ..admin import HasLeaderFilter, GroupAdmin, Group
 from . import get_admin_change_view_url
+from ..models import ReservedGroupName
+
 
 if 'allianceauth.eveonline.autogroups' in settings.INSTALLED_APPS:
     _has_auto_groups = True
@@ -25,8 +26,8 @@ else:
 MODULE_PATH = 'allianceauth.groupmanagement.admin'
 
 
-class MockRequest(object):
-    
+class MockRequest:
+
     def __init__(self, user=None):
         self.user = user
 
@@ -38,7 +39,7 @@ class TestGroupAdmin(TestCase):
         super().setUpClass()
 
         # group 1 - has leader
-        cls.group_1 = Group.objects.create(name='Group 1')        
+        cls.group_1 = Group.objects.create(name='Group 1')
         cls.group_1.authgroup.description = 'Default Group'
         cls.group_1.authgroup.internal = False
         cls.group_1.authgroup.hidden = False
@@ -47,7 +48,8 @@ class TestGroupAdmin(TestCase):
         # group 2 - no leader
         cls.group_2 = Group.objects.create(name='Group 2')
         cls.group_2.authgroup.description = 'Internal Group'
-        cls.group_2.authgroup.internal = True        
+        cls.group_2.authgroup.internal = True
+        cls.group_2.authgroup.group_leader_groups.add(cls.group_1)
         cls.group_2.authgroup.save()
 
         # group 3 - has leader
@@ -81,7 +83,7 @@ class TestGroupAdmin(TestCase):
         cls.group_6.authgroup.open = True
         cls.group_6.authgroup.public = True
         cls.group_6.authgroup.save()
-        
+
         # user 1 - corp and alliance, normal user
         cls.character_1 = EveCharacter.objects.create(
             character_id=1001,
@@ -106,16 +108,16 @@ class TestGroupAdmin(TestCase):
         alliance = EveAllianceInfo.objects.create(
             alliance_id=3001,
             alliance_name='Wayne Enterprises',
-            alliance_ticker='WE',            
+            alliance_ticker='WE',
             executor_corp_id=2001
         )
         EveCorporationInfo.objects.create(
             corporation_id=2001,
             corporation_name='Wayne Technologies',
-            corporation_ticker='WT',            
+            corporation_ticker='WT',
             member_count=42,
             alliance=alliance
-        )        
+        )
         cls.user_1 = User.objects.create_user(
             cls.character_1.character_name.replace(' ', '_'),
             'abc@example.com',
@@ -148,7 +150,7 @@ class TestGroupAdmin(TestCase):
         EveCorporationInfo.objects.create(
             corporation_id=2002,
             corporation_name='Daily Plane',
-            corporation_ticker='DP',            
+            corporation_ticker='DP',
             member_count=99,
             alliance=None
         )
@@ -167,7 +169,7 @@ class TestGroupAdmin(TestCase):
         cls.user_2.groups.add(cls.group_2)
         cls.user_2.is_staff = True
         cls.user_2.save()
-        
+
         # user 3 - no main, no group, superuser
         cls.character_3 = EveCharacter.objects.create(
             character_id=1101,
@@ -180,7 +182,7 @@ class TestGroupAdmin(TestCase):
         EveCorporationInfo.objects.create(
             corporation_id=2101,
             corporation_name='Lex Corp',
-            corporation_ticker='LC',            
+            corporation_ticker='LC',
             member_count=666,
             alliance=None
         )
@@ -222,7 +224,7 @@ class TestGroupAdmin(TestCase):
             for state in State.objects.all():
                 autogroups_config.states.add(state)
             autogroups_config.update_corp_group_membership(self.user_1)
-    
+
     # column rendering
 
     def test_description(self):
@@ -230,17 +232,21 @@ class TestGroupAdmin(TestCase):
         result = self.modeladmin._description(self.group_1)
         self.assertEqual(result, expected)
 
-    def test_member_count(self):        
+    def test_member_count(self):
         expected = 1
         obj = self.modeladmin.get_queryset(MockRequest(user=self.user_1))\
             .get(pk=self.group_1.pk)
         result = self.modeladmin._member_count(obj)
         self.assertEqual(result, expected)
 
-    def test_has_leader(self):        
+    def test_has_leader_user(self):
         result = self.modeladmin.has_leader(self.group_1)
         self.assertTrue(result)
 
+    def test_has_leader_group(self):
+        result = self.modeladmin.has_leader(self.group_2)
+        self.assertTrue(result)
+
     def test_properties_1(self):
         expected = ['Default']
         result = self.modeladmin._properties(self.group_1)
@@ -283,17 +289,17 @@ class TestGroupAdmin(TestCase):
             self.assertListEqual(result, expected)
 
     # actions
-   
+
     # filters
-    
+
     if _has_auto_groups:
         @patch(MODULE_PATH + '._has_auto_groups', True)
         def test_filter_is_auto_group(self):
-            
-            class GroupAdminTest(admin.ModelAdmin): 
+
+            class GroupAdminTest(admin.ModelAdmin):
                 list_filter = (IsAutoGroupFilter,)
-                    
-            self._create_autogroups()        
+
+            self._create_autogroups()
             my_modeladmin = GroupAdminTest(Group, AdminSite())
 
             # Make sure the lookups are correct
@@ -333,17 +339,17 @@ class TestGroupAdmin(TestCase):
             changelist = my_modeladmin.get_changelist_instance(request)
             queryset = changelist.get_queryset(request)
             expected = Group.objects.exclude(
-                managedalliancegroup__isnull=True, 
+                managedalliancegroup__isnull=True,
                 managedcorpgroup__isnull=True
             )
             self.assertSetEqual(set(queryset), set(expected))
-         
+
     def test_filter_has_leader(self):
-        
-        class GroupAdminTest(admin.ModelAdmin): 
+
+        class GroupAdminTest(admin.ModelAdmin):
             list_filter = (HasLeaderFilter,)
-                
-        self._create_autogroups()        
+
+        self._create_autogroups()
         my_modeladmin = GroupAdminTest(Group, AdminSite())
 
         # Make sure the lookups are correct
@@ -378,16 +384,121 @@ class TestGroupAdmin(TestCase):
         changelist = my_modeladmin.get_changelist_instance(request)
         queryset = changelist.get_queryset(request)
         expected = [
-            self.group_1,            
+            self.group_1,
             self.group_3
         ]
         self.assertSetEqual(set(queryset), set(expected))
-    
+
     def test_change_view_loads_normally(self):
         User.objects.create_superuser(
             username='superuser', password='secret', email='admin@example.com'
         )
         c = Client()
-        c.login(username='superuser', password='secret')                
+        c.login(username='superuser', password='secret')
         response = c.get(get_admin_change_view_url(self.group_1))
         self.assertEqual(response.status_code, 200)
+
+    def test_should_create_new_group(self):
+        # given
+        user = User.objects.create_superuser("bruce")
+        self.client.force_login(user)
+        # when
+        response = self.client.post(
+            "/admin/groupmanagement/group/add/",
+            data={
+                "name": "new group",
+                "authgroup-TOTAL_FORMS": 1,
+                "authgroup-INITIAL_FORMS": 0,
+                "authgroup-MIN_NUM_FORMS": 0,
+                "authgroup-MAX_NUM_FORMS": 1,
+            }
+        )
+        # then
+        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.url, "/admin/groupmanagement/group/")
+        self.assertTrue(Group.objects.filter(name="new group").exists())
+
+    def test_should_not_allow_creating_new_group_with_reserved_name(self):
+        # given
+        ReservedGroupName.objects.create(
+            name="new group", reason="dummy", created_by="bruce"
+        )
+        user = User.objects.create_superuser("bruce")
+        self.client.force_login(user)
+        # when
+        response = self.client.post(
+            "/admin/groupmanagement/group/add/",
+            data={
+                "name": "New group",
+                "authgroup-TOTAL_FORMS": 1,
+                "authgroup-INITIAL_FORMS": 0,
+                "authgroup-MIN_NUM_FORMS": 0,
+                "authgroup-MAX_NUM_FORMS": 1,
+            }
+        )
+        # then
+        self.assertContains(
+            response, "This name has been reserved and can not be used for groups"
+        )
+        self.assertFalse(Group.objects.filter(name="new group").exists())
+
+    def test_should_not_allow_changing_name_of_existing_group_to_reserved_name(self):
+        # given
+        ReservedGroupName.objects.create(
+            name="new group", reason="dummy", created_by="bruce"
+        )
+        group = Group.objects.create(name="dummy")
+        user = User.objects.create_superuser("bruce")
+        self.client.force_login(user)
+        # when
+        response = self.client.post(
+            f"/admin/groupmanagement/group/{group.pk}/change/",
+            data={
+                "name": "new group",
+                "authgroup-TOTAL_FORMS": 1,
+                "authgroup-INITIAL_FORMS": 0,
+                "authgroup-MIN_NUM_FORMS": 0,
+                "authgroup-MAX_NUM_FORMS": 1,
+            }
+        )
+        # then
+        self.assertContains(
+            response, "This name has been reserved and can not be used for groups"
+        )
+        self.assertFalse(Group.objects.filter(name="new group").exists())
+
+
+class TestReservedGroupNameAdmin(TestCase):
+    @classmethod
+    def setUpClass(cls):
+        super().setUpClass()
+        cls.user = User.objects.create_superuser("bruce")
+
+    def test_should_create_new_entry(self):
+        # given
+        self.client.force_login(self.user)
+        # when
+        response = self.client.post(
+            "/admin/groupmanagement/reservedgroupname/add/",
+            data={"name": "Test", "reason": "dummy"}
+        )
+        # then
+        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response.url, "/admin/groupmanagement/reservedgroupname/")
+        obj = ReservedGroupName.objects.get(name="test")
+        self.assertEqual(obj.name, "test")
+        self.assertEqual(obj.created_by, self.user.username)
+        self.assertTrue(obj.created_at)
+
+    def test_should_not_allow_names_of_existing_groups(self):
+        # given
+        Group.objects.create(name="Already taken")
+        self.client.force_login(self.user)
+        # when
+        response = self.client.post(
+            "/admin/groupmanagement/reservedgroupname/add/",
+            data={"name": "already taken", "reason": "dummy"}
+        )
+        # then
+        self.assertContains(response, "There already exists a group with that name")
+        self.assertFalse(ReservedGroupName.objects.filter(name="already taken").exists())
