@@ -6,9 +6,25 @@ from django.utils import timezone
 from allianceauth.eveonline.models import EveCharacter
 
 
+class OpTimerType(models.Model):
+    """
+    Optimer Type
+    """
+
+    type = models.CharField(max_length=254, default="")
+
+    def __str__(self):
+        return self.type
+
+    class Meta:
+        ordering = ['type']
+        default_permissions = ()
+
+
 class OpTimer(models.Model):
     class Meta:
         ordering = ['start']
+        default_permissions = ()
 
     doctrine = models.CharField(max_length=254, default="")
     system = models.CharField(max_length=254, default="")
@@ -17,7 +33,10 @@ class OpTimer(models.Model):
     operation_name = models.CharField(max_length=254, default="")
     fc = models.CharField(max_length=254, default="")
     post_time = models.DateTimeField(default=timezone.now)
-    eve_character = models.ForeignKey(EveCharacter, null=True, on_delete=models.SET_NULL)
+    eve_character = models.ForeignKey(EveCharacter, null=True,
+                                      on_delete=models.SET_NULL)
+    description = models.TextField(blank=True, default="")
+    type = models.ForeignKey(OpTimerType, null=True, on_delete=models.SET_NULL)
 
     def __str__(self):
         return self.operation_name
